import React, { useState, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleBand, scaleLinear, max } from 'd3';

// Assuming your CSV is hosted and accessible via a URL
const csvUrl =
  'https://gist.githubusercontent.com/Mukunda799/e20eb77654e6341a5c30ca45b334d516/raw/781c31a088e49a38296094f4c2ccd9449d8880b6/carssales.csv';
const width = 960;
const height = 500;
const margin = {
  top: 20,
  right: 20,
  bottom: 50,
  left: 200,
};

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = (d) => {
      d.Price = +d['Price']; // Convert the Price column to numbers
      return d;
    };
    csv(csvUrl, row).then(setData);
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  // Group data by Brand and calculate average price
  const priceByBrand = Array.from(
    data.reduce(
      (acc, d) =>
        acc.set(
          d.Brand,
          (acc.get(d.Brand) || []).concat(d.Price),
        ),
      new Map(),
    ),
    ([Brand, prices]) => ({
      Brand,
      AveragePrice:
        prices.reduce((a, b) => a + b, 0) / prices.length,
    }),
  );

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const yScale = scaleBand()
    .domain(priceByBrand.map((d) => d.Brand))
    .range([0, innerHeight])
    .padding(0.1);

  const xScale = scaleLinear()
    .domain([0, max(priceByBrand, (d) => d.AveragePrice)])
    .range([0, innerWidth]);

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left},${margin.top})`}
      >
        {xScale.ticks().map((tickValue) => (
          <g
            key={tickValue}
            transform={`translate(${xScale(tickValue)},0)`}
          >
            <line y2={innerHeight} stroke="#c0c0c0" />
            <text
              style={{ textAnchor: 'middle' }}
              dy=".71em"
              y={innerHeight + 3}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map((tickValue) => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".32em"
            y={yScale(tickValue) + yScale.bandwidth() / 2}
          >
            {tickValue}
          </text>
        ))}
        {priceByBrand.map((d) => (
          <rect
            key={d.Brand}
            y={yScale(d.Brand)}
            width={xScale(d.AveragePrice)}
            height={yScale.bandwidth()}
          />
        ))}
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
